#
# spec file for package rtkit
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rtkit
Version:        0.11+git.20130926
Release:        lp150.1.8
Summary:        Realtime Policy and Watchdog Daemon
License:        GPL-3.0+ and BSD-3-Clause
Group:          System/Base
# The daemon itself is GPL v3 or later, the reference implementation for
# the client BSD-3-Clause
Url:            http://git.0pointer.de/?p=rtkit.git
Source:         %{name}-%{version}.tar.xz
Patch2:         rtkit-no-cpu-controlgroup.patch
BuildRequires:  automake
BuildRequires:  libcap-devel
BuildRequires:  pkg-config
BuildRequires:  xz
BuildRequires:  pkgconfig(dbus-1) >= 1.2
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(polkit-agent-1)
BuildRequires:  pkgconfig(polkit-gobject-1)
Requires:       polkit
Requires(pre):  dbus-1
Provides:       %{name} = 0.11_git201205151338
Obsoletes:      %{name} = 0.11_git201205151338
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
RealtimeKit is a D-Bus system service that changes the scheduling policy of
user processes/threads to SCHED_RR (i.e. realtime scheduling mode) on
request. It is intended to be used as a secure mechanism to allow real-time
scheduling to be used by normal user processes.

%prep
%setup -q
%patch2 -p1

%build
autoreconf -fiv
export CFLAGS="%{optflags} -fPIE"
export LDFLAGS="-Wl,-z,relro,-z,now -pie"
%configure \
  --disable-silent-rules \
  --with-systemdsystemunitdir=%{_unitdir} \
  --libexecdir=%{_libexecdir}/rtkit

make %{?_smp_mflags}
./rtkit-daemon --introspect > org.freedesktop.RealtimeKit1.xml

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
ln -sv %{_sbindir}/service %{buildroot}%{_sbindir}/rcrtkit-daemon
install -D -m 0644 org.freedesktop.RealtimeKit1.xml %{buildroot}/%{_datadir}/dbus-1/interfaces/org.freedesktop.RealtimeKit1.xml

%preun
%service_del_preun rtkit-daemon.service

%pre
groupadd -r rtkit >/dev/null 2>&1 || :
%{_bindir}/id rtkit >/dev/null 2>&1 || \
        useradd -r -g rtkit -c 'RealtimeKit' -s /bin/false -d /proc rtkit

%service_add_pre rtkit-daemon.service

%post
dbus-send --system --type=method_call --dest=org.freedesktop.DBus / org.freedesktop.DBus.ReloadConfig >/dev/null 2>&1 || :
%service_add_post rtkit-daemon.service

%postun
%service_del_postun rtkit-daemon.service

%files
%defattr(0644,root,root,0755)
%doc README GPL LICENSE rtkit.c rtkit.h
%attr(0755,root,root) %{_sbindir}/rtkitctl
%dir %{_libexecdir}/rtkit
%attr(0755,root,root) %{_libexecdir}/rtkit/rtkit-daemon
%{_datadir}/dbus-1/system-services/org.freedesktop.RealtimeKit1.service
%{_datadir}/dbus-1/interfaces/org.freedesktop.RealtimeKit1.xml
%{_datadir}/polkit-1/actions/org.freedesktop.RealtimeKit1.policy
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.RealtimeKit1.conf
%{_mandir}/man8/rtkitctl.8%{ext_man}
%{_sbindir}/rcrtkit-daemon
%{_unitdir}/rtkit-daemon.service

%changelog
* Fri Dec  9 2016 fbui@suse.com
- Drop BR on libsystemd-daemon as rtkit uses a fancy way to reuse
  systemd code :)
* Sun May  8 2016 mpluskal@suse.com
- Add proper provides/obsoletes due to small change in versioning
* Mon Apr 18 2016 mpluskal@suse.com
- Update to version 0.11+git.20130926:
  * Pass uid of caller to polkit
  * build-sys: since clock_gettime() moved to libc use mq_open to
    check for librt
  * systemd: update sd-daemon.[ch]
- Drop upstreamed patches
  * rtkit-bnc836939.patch
  * rtkit-use-system-sd-daemon.patch
- Add _service
- Cleanup spec file with spec-cleaner
- Drop support for pre systemd ditributions
- Add rc symlink for service
- Use more strict ldflags
* Thu Jan  1 2015 meissner@suse.com
- build with PIE
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Thu Feb 27 2014 meissner@suse.com
- rtkit-no-cpu-controlgroup.patch: do not specify the cpu: ControlGroup,
  unsupported by systemd currently. bnc#847948
* Fri Sep 27 2013 sreeves@suse.com
- Add rtkit-bnc836939.patch
  Fix bnc#836939 - use of insecure polkit DBUS API. CVE-2013-4326
* Wed Oct 17 2012 fcrozat@suse.com
- Don't buildrequires systemd, it is pulled by
  pkgconfig(libsystemd-daemon), fixes conflict when bootstrapping
  with systemd-mini packages.
* Sun Sep 23 2012 crrodriguez@opensuse.org
- rtkit-use-system-sd-daemon.patch Use system sddaemon libs.
* Sun Sep 23 2012 crrodriguez@opensuse.org
- Update to version 0.11.x, not much has changed other
  than systemd related updates/improvements.
* Tue Dec 20 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu Dec  8 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Dec  2 2011 crrodriguez@opensuse.org
- Update to version 0.10.x
  * fix annoying warning
  Failed to make ourselves RT: Invalid argument [bnc#551777]
  * activation is now done with systemd if possible
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Mon Jan 25 2010 sreeves@novell.com
- Update to version 0.5
  + By default don't demote unknown threads
- bnc#572989 - change to /bin/false
* Fri Aug 14 2009 sreeves@novell.com
- Initial package
